You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@weex.apache.org by ac...@apache.org on 2017/07/29 02:56:00 UTC

[01/12] incubator-weex git commit: * [android] RecyclerView Memory optimization

Repository: incubator-weex
Updated Branches:
  refs/heads/0.16-dev b11c4e113 -> 53edff05b


* [android] RecyclerView Memory optimization


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/1a871981
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/1a871981
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/1a871981

Branch: refs/heads/0.16-dev
Commit: 1a871981d0d8af344f4abb8ca1fe927f0d4848c7
Parents: f63bf2c
Author: miomin <69...@qq.com>
Authored: Tue Jul 25 16:51:32 2017 +0800
Committer: miomin <69...@qq.com>
Committed: Tue Jul 25 16:51:32 2017 +0800

----------------------------------------------------------------------
 .../weex/ui/component/list/BasicListComponent.java    | 14 ++++++++++++--
 1 file changed, 12 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/1a871981/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
----------------------------------------------------------------------
diff --git a/ios/sdk/WeexSDK.xcodeproj/project.pbxproj b/ios/sdk/WeexSDK.xcodeproj/project.pbxproj
index 4520dc1..5785c45 100644
--- a/ios/sdk/WeexSDK.xcodeproj/project.pbxproj
+++ b/ios/sdk/WeexSDK.xcodeproj/project.pbxproj
@@ -530,6 +530,8 @@
 		DCC77C131D770AE300CE7288 /* WXSliderNeighborComponent.m in Sources */ = {isa = PBXBuildFile; fileRef = DCC77C111D770AE300CE7288 /* WXSliderNeighborComponent.m */; };
 		DCC77C141D770AE300CE7288 /* WXSliderNeighborComponent.h in Headers */ = {isa = PBXBuildFile; fileRef = DCC77C121D770AE300CE7288 /* WXSliderNeighborComponent.h */; };
 		DCDFED011E68238F00C228D7 /* WXJSExceptionProtocol.h in Headers */ = {isa = PBXBuildFile; fileRef = DCDFED001E68238F00C228D7 /* WXJSExceptionProtocol.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		DCEA54621F2B7DB4000ECB23 /* WXTracingManager.h in Headers */ = {isa = PBXBuildFile; fileRef = C4E97D311F1EF46D00ABC314 /* WXTracingManager.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		DCEA54631F2B7DBA000ECB23 /* WXTracingManager.m in Sources */ = {isa = PBXBuildFile; fileRef = C4E97D321F1EF46D00ABC314 /* WXTracingManager.m */; };
 		DCF087611DCAE161005CD6EB /* WXInvocationConfig.h in Headers */ = {isa = PBXBuildFile; fileRef = DCF0875F1DCAE161005CD6EB /* WXInvocationConfig.h */; };
 		DCF087621DCAE161005CD6EB /* WXInvocationConfig.m in Sources */ = {isa = PBXBuildFile; fileRef = DCF087601DCAE161005CD6EB /* WXInvocationConfig.m */; };
 		DCF0CD9E1EAF3A6B0062CA8F /* native-bundle-main.js in Resources */ = {isa = PBXBuildFile; fileRef = DCF0CD9D1EAF3A6B0062CA8F /* native-bundle-main.js */; };
@@ -1746,6 +1748,7 @@
 				DCA445D91EFA59A100D0CFA8 /* WXEditComponent.h in Headers */,
 				DCA445FB1EFA5A3C00D0CFA8 /* WXStorageModule.h in Headers */,
 				DCA446051EFA5A5800D0CFA8 /* WXBoxShadow.h in Headers */,
+				DCEA54621F2B7DB4000ECB23 /* WXTracingManager.h in Headers */,
 				DCA445D11EFA594200D0CFA8 /* WXLayer.h in Headers */,
 				DCA4460A1EFA5A6F00D0CFA8 /* WXSimulatorShortcutManager.h in Headers */,
 				DCA445E11EFA59D100D0CFA8 /* WXSliderNeighborComponent.h in Headers */,
@@ -2196,6 +2199,7 @@
 				DCA445801EFA55B300D0CFA8 /* WXLength.m in Sources */,
 				DCA445811EFA55B300D0CFA8 /* WXDiffUtil.m in Sources */,
 				DCA445821EFA55B300D0CFA8 /* WXSDKEngine.m in Sources */,
+				DCEA54631F2B7DBA000ECB23 /* WXTracingManager.m in Sources */,
 				DCA445831EFA55B300D0CFA8 /* WXBridgeMethod.m in Sources */,
 				DCA445841EFA55B300D0CFA8 /* WXModuleMethod.m in Sources */,
 				DCA445851EFA55B300D0CFA8 /* WXComponentMethod.m in Sources */,


[07/12] incubator-weex git commit: Merge branch '0.15-dev-xy' into 0.15-dev

Posted by ac...@apache.org.
Merge branch '0.15-dev-xy' into 0.15-dev

* 0.15-dev-xy:
  * [android] visibleCellCount need to be considered columnCount
  * [android] RecyclerView Memory optimization


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/5cb9fc7e
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/5cb9fc7e
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/5cb9fc7e

Branch: refs/heads/0.16-dev
Commit: 5cb9fc7eb37f5edbc62d17246082f2fae5ff13d1
Parents: 821164c 0bf8ebe
Author: zshshr <zh...@gmail.com>
Authored: Thu Jul 27 10:27:28 2017 +0800
Committer: zshshr <zh...@gmail.com>
Committed: Thu Jul 27 10:27:28 2017 +0800

----------------------------------------------------------------------
 .../weex/ui/component/list/BasicListComponent.java   | 15 +++++++++++++--
 1 file changed, 13 insertions(+), 2 deletions(-)
----------------------------------------------------------------------



[04/12] incubator-weex git commit: + [android] add newNestedInstance method in WXSDKInstance

Posted by ac...@apache.org.
+ [android] add newNestedInstance method in WXSDKInstance


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/bf9fe0dc
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/bf9fe0dc
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/bf9fe0dc

Branch: refs/heads/0.16-dev
Commit: bf9fe0dc284e7ba3881b2e6701127ce08572bdb5
Parents: ee9b1c7
Author: lybeen <il...@gmail.com>
Authored: Wed Jul 26 16:42:38 2017 +0800
Committer: lybeen <il...@gmail.com>
Committed: Wed Jul 26 16:42:38 2017 +0800

----------------------------------------------------------------------
 android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/bf9fe0dc/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java b/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
index a8d8a60..7f03cc2 100644
--- a/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
+++ b/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
@@ -250,14 +250,18 @@ public class WXSDKInstance implements IWXActivityStateListener,DomContext, View.
     mNestedInstanceInterceptor = interceptor;
   }
 
-  public WXSDKInstance createNestedInstance(NestedContainer container){
-    WXSDKInstance sdkInstance = new WXSDKInstance(mContext);
+  public final WXSDKInstance createNestedInstance(NestedContainer container){
+    WXSDKInstance sdkInstance = newNestedInstance();
     if(mNestedInstanceInterceptor != null){
       mNestedInstanceInterceptor.onCreateNestInstance(sdkInstance,container);
     }
     return sdkInstance;
   }
 
+  protected WXSDKInstance newNestedInstance() {
+    return new WXSDKInstance(mContext);
+  }
+
   public void addOnInstanceVisibleListener(OnInstanceVisibleListener l){
     mVisibleListeners.add(l);
   }


[08/12] incubator-weex git commit: * [android] fix WXSDKInstance filed mComponentObserver memory leak

Posted by ac...@apache.org.
* [android] fix WXSDKInstance filed mComponentObserver memory leak


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/9050d48c
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/9050d48c
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/9050d48c

Branch: refs/heads/0.16-dev
Commit: 9050d48cd8d15273a5101574025c90aff62cbe9e
Parents: 5cb9fc7
Author: atomtong <to...@qq.com>
Authored: Thu Jul 27 15:55:32 2017 +0800
Committer: atomtong <to...@qq.com>
Committed: Thu Jul 27 15:55:32 2017 +0800

----------------------------------------------------------------------
 android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java | 3 +++
 1 file changed, 3 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/9050d48c/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java b/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
index 7f03cc2..4a1b06e 100644
--- a/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
+++ b/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
@@ -1212,6 +1212,9 @@ public class WXSDKInstance implements IWXActivityStateListener,DomContext, View.
       mGlobalEvents.clear();
     }
 
+    if(mComponentObserver != null){
+        mComponentObserver = null;
+    }
 
     mNestedInstanceInterceptor = null;
     mUserTrackAdapter = null;


[09/12] incubator-weex git commit: * [ios] rid compiler warnings

Posted by ac...@apache.org.
* [ios] rid compiler warnings


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/6b9f8621
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/6b9f8621
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/6b9f8621

Branch: refs/heads/0.16-dev
Commit: 6b9f86219f3871e36bad43ffd635218f24452759
Parents: 9050d48
Author: acton393 <zh...@gmail.com>
Authored: Fri Jul 28 21:38:19 2017 +0800
Committer: acton393 <zh...@gmail.com>
Committed: Fri Jul 28 21:38:19 2017 +0800

----------------------------------------------------------------------
 ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h | 1 -
 ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m | 1 +
 2 files changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/6b9f8621/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h
----------------------------------------------------------------------
diff --git a/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h b/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h
index 52c291e..dd1d765 100644
--- a/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h
+++ b/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h
@@ -19,7 +19,6 @@
 
 #import <Foundation/Foundation.h>
 #import "WXModuleProtocol.h"
-#import "SRWebSocket.h"
 
 @interface WXWebSocketModule : NSObject <WXModuleProtocol>
 

http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/6b9f8621/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m
----------------------------------------------------------------------
diff --git a/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m b/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m
index c752d9f..018103a 100644
--- a/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m
+++ b/ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m
@@ -23,6 +23,7 @@
 #import "WXHandlerFactory.h"
 #import "WXWebSocketLoader.h"
 #import "WXConvert.h"
+#import "SRWebSocket.h"
 
 @interface WXWebSocketModule()
 


[06/12] incubator-weex git commit: Merge branch '0.15-dev' of https://git-wip-us.apache.org/repos/asf/incubator-weex into ios-tracing-0.15-dev

Posted by ac...@apache.org.
Merge branch '0.15-dev' of https://git-wip-us.apache.org/repos/asf/incubator-weex into ios-tracing-0.15-dev


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/821164cf
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/821164cf
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/821164cf

Branch: refs/heads/0.16-dev
Commit: 821164cfa4e92d1a7b75ac799b168612a208063b
Parents: c4c77dc bf9fe0d
Author: 齐山 <su...@163.com>
Authored: Wed Jul 26 17:48:25 2017 +0800
Committer: 齐山 <su...@163.com>
Committed: Wed Jul 26 17:48:25 2017 +0800

----------------------------------------------------------------------
 android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)
----------------------------------------------------------------------



[03/12] incubator-weex git commit: Merge branch '0.15-dev' of https://github.com/apache/incubator-weex into 0.15-dev

Posted by ac...@apache.org.
Merge branch '0.15-dev' of https://github.com/apache/incubator-weex into 0.15-dev


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/0bf8ebe6
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/0bf8ebe6
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/0bf8ebe6

Branch: refs/heads/0.16-dev
Commit: 0bf8ebe6b6078187971553dffe7a501d0f650405
Parents: b911649 ee9b1c7
Author: miomin <69...@qq.com>
Authored: Wed Jul 26 16:37:14 2017 +0800
Committer: miomin <69...@qq.com>
Committed: Wed Jul 26 16:37:14 2017 +0800

----------------------------------------------------------------------
 examples/vue/components/input.vue               |  17 +
 html5/test/render/vue/core/node.js              |  10 +-
 .../render/vue/data/dotvue/event-bubble-bar.vue |  11 -
 .../render/vue/data/dotvue/event-bubble.vue     |  11 -
 .../WeexDemo.xcodeproj/project.pbxproj          |   4 +
 ios/playground/WeexDemo/WXDemoViewController.m  |   2 +-
 ios/sdk/WeexSDK.xcodeproj/project.pbxproj       |   8 +
 .../WeexSDK/Sources/Bridge/WXBridgeContext.m    |  34 +-
 ios/sdk/WeexSDK/Sources/Bridge/WXBridgeMethod.m |  16 +-
 ios/sdk/WeexSDK/Sources/Bridge/WXJSCoreBridge.m |  33 +-
 .../WeexSDK/Sources/Component/WXEditComponent.m |   2 +-
 .../Sources/Component/WXImageComponent.m        |   1 +
 .../Sources/Component/WXScrollerComponent.m     |   1 +
 .../WeexSDK/Sources/Component/WXTextComponent.m |   1 +
 .../Sources/Manager/WXComponentManager.m        |   5 +-
 .../WeexSDK/Sources/Manager/WXTracingManager.h  | 126 ++++++
 .../WeexSDK/Sources/Manager/WXTracingManager.m  | 384 +++++++++++++++++++
 ios/sdk/WeexSDK/Sources/Model/WXComponent.m     |   3 +
 .../WeexSDK/Sources/Model/WXJSExceptionInfo.h   |   1 +
 ios/sdk/WeexSDK/Sources/Model/WXSDKInstance.m   |   7 +
 .../WeexSDK/Sources/Module/WXAnimationModule.m  |   7 +-
 ios/sdk/WeexSDK/Sources/Module/WXDomModule.m    |   4 +-
 .../WeexSDK/Sources/Protocol/WXBridgeProtocol.h |   5 +
 ios/sdk/WeexSDK/Sources/Utility/WXLog.m         |   8 +
 .../Sources/View/WXComponent+ViewManagement.m   |   3 +-
 ios/sdk/WeexSDK/Sources/WeexSDK.h               |   1 +
 pre-build/native-bundle-main.js                 |  12 +-
 27 files changed, 660 insertions(+), 57 deletions(-)
----------------------------------------------------------------------



[02/12] incubator-weex git commit: * [android] visibleCellCount need to be considered columnCount

Posted by ac...@apache.org.
* [android] visibleCellCount need to be considered columnCount


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/b9116490
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/b9116490
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/b9116490

Branch: refs/heads/0.16-dev
Commit: b9116490531918754565f8b9fddd6e44393c6786
Parents: 1a87198
Author: miomin <69...@qq.com>
Authored: Tue Jul 25 17:04:17 2017 +0800
Committer: miomin <69...@qq.com>
Committed: Tue Jul 25 17:04:17 2017 +0800

----------------------------------------------------------------------
 .../com/taobao/weex/ui/component/list/BasicListComponent.java     | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/b9116490/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
index b85ec21..c959351 100644
--- a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
@@ -1196,7 +1196,8 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
       direction = directionX > 0 ? Constants.Value.DIRECTION_LEFT : Constants.Value.DIRECTION_RIGHT;
     }
 
-    visibleCellCount = lastVisible - firstVisible;
+    if (mColumnCount > 0)
+      visibleCellCount = (lastVisible - firstVisible) * mColumnCount;
 
     while (it.hasNext()) {
       AppearanceHelper item = it.next();


[12/12] incubator-weex git commit: Merge branch '0.16-dev' of https://git-wip-us.apache.org/repos/asf/incubator-weex into wip-us-0.16-dev

Posted by ac...@apache.org.
Merge branch '0.16-dev' of https://git-wip-us.apache.org/repos/asf/incubator-weex into wip-us-0.16-dev


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/53edff05
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/53edff05
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/53edff05

Branch: refs/heads/0.16-dev
Commit: 53edff05bd1a4fcec36d03eb8025b7d3b3fc08ea
Parents: 2377bf6 b11c4e1
Author: acton393 <zh...@gmail.com>
Authored: Sat Jul 29 10:55:46 2017 +0800
Committer: acton393 <zh...@gmail.com>
Committed: Sat Jul 29 10:55:46 2017 +0800

----------------------------------------------------------------------
 .gitignore                                      |   3 +
 build/build.js                                  | 105 +++-
 build/config.js                                 |  37 +-
 dangerfile.js                                   |  35 +-
 entry.js                                        |  11 +
 html5/render/vue/README.md                      |  77 +++
 html5/render/vue/components/a.js                |  90 +--
 html5/render/vue/components/div.js              |  43 +-
 html5/render/vue/components/image.js            |  18 +-
 html5/render/vue/components/index.js            |  37 +-
 html5/render/vue/components/input.js            | 130 +++--
 html5/render/vue/components/scrollable/cell.js  |  39 ++
 .../render/vue/components/scrollable/header.js  | 102 ++--
 html5/render/vue/components/scrollable/index.js |  48 ++
 html5/render/vue/components/scrollable/list.js  |  82 +++
 .../vue/components/scrollable/list/cell.js      |  36 --
 .../vue/components/scrollable/list/index.js     |  77 ---
 .../vue/components/scrollable/list/listMixin.js |  47 --
 .../vue/components/scrollable/list/style.js     |  34 --
 .../components/scrollable/loading-indicator.js  |  17 +-
 .../render/vue/components/scrollable/loading.js | 141 ++---
 .../vue/components/scrollable/mixins/index.js   |  26 +
 .../vue/components/scrollable/mixins/list.js    |  46 ++
 .../components/scrollable/mixins/scrollable.js  | 267 +++++++++
 .../render/vue/components/scrollable/refresh.js | 157 ++---
 .../vue/components/scrollable/scroller.js       | 135 +++--
 .../render/vue/components/scrollable/style.css  |  85 +++
 .../vue/components/scrollable/waterfall.js      | 573 ++++++++++---------
 html5/render/vue/components/slider/index.js     |  52 +-
 html5/render/vue/components/slider/indicator.js |  18 +-
 .../render/vue/components/slider/slideMixin.js  |  46 +-
 .../vue/components/slider/slider-neighbor.js    |  12 +-
 html5/render/vue/components/slider/slider.css   |  19 +
 html5/render/vue/components/slider/slider.js    |  75 +++
 html5/render/vue/components/switch.js           | 114 ++--
 html5/render/vue/components/text.js             |  52 +-
 html5/render/vue/components/textarea.js         | 104 ++--
 html5/render/vue/components/video.js            | 107 ++--
 html5/render/vue/components/web.js              |  98 ++--
 html5/render/vue/core/style.js                  |  35 --
 html5/render/vue/env/global.js                  |   6 +
 html5/render/vue/env/index.js                   |   5 -
 html5/render/vue/index.js                       |  25 -
 html5/render/vue/mixins/base.js                 |  71 ---
 html5/render/vue/mixins/index.js                |   2 -
 html5/render/vue/mixins/scrollable.js           | 233 --------
 html5/render/vue/mixins/style.js                |   4 +-
 html5/render/vue/modules/animation.js           |  36 +-
 html5/render/vue/modules/dom.js                 |  21 +-
 html5/render/vue/modules/globalEvent.js         |   8 +-
 html5/render/vue/modules/index.js               |  36 +-
 html5/render/vue/modules/navigator.js           |  10 +-
 html5/render/vue/modules/webview.js             |  18 +-
 html5/render/vue/styles/base.css                |  86 +--
 html5/render/vue/styles/reset.css               |  19 +
 html5/render/vue/utils/lazyload.js              |  24 +-
 html5/render/vue/utils/perf.js                  | 283 +--------
 html5/test/render/vue/components/list.js        |   2 +-
 html5/test/render/vue/components/switch.js      |   5 +-
 html5/test/render/vue/examples/list-cell.js     |   2 +-
 html5/test/render/vue/helper/index.js           |   2 +-
 html5/test/render/vue/helper/main.js            |   3 +-
 html5/test/render/vue/helper/utils.js           |   4 +
 html5/test/render/vue/modules/animation.js      |  12 +-
 html5/test/render/vue/modules/dom.js            |  10 +-
 html5/test/render/vue/modules/globalEvent.js    |   8 +-
 html5/test/render/vue/modules/navigator.js      |   8 +-
 html5/test/render/vue/modules/webview.js        |  10 +-
 html5/test/render/vue/utils/lazyload.js         |  59 +-
 html5/test/render/vue/utils/perf.js             |  94 +--
 html5/test/render/vue/utils/style.js            |  50 +-
 package.json                                    |  19 +-
 packages/weex-vue-plugins/weex-vue-a/README.md  |   3 +
 .../weex-vue-plugins/weex-vue-a/package.json    |  26 +
 .../weex-vue-plugins/weex-vue-a/src/index.js    |   2 +
 .../weex-vue-animation/README.md                |   3 +
 .../weex-vue-animation/package.json             |  27 +
 .../weex-vue-animation/src/index.js             |   2 +
 .../weex-vue-clipboard/README.md                |   3 +
 .../weex-vue-clipboard/package.json             |  27 +
 .../weex-vue-clipboard/src/index.js             |   2 +
 .../weex-vue-plugins/weex-vue-dom/README.md     |   3 +
 .../weex-vue-plugins/weex-vue-dom/package.json  |  27 +
 .../weex-vue-plugins/weex-vue-dom/src/index.js  |   2 +
 .../weex-vue-plugins/weex-vue-event/README.md   |   3 +
 .../weex-vue-event/package.json                 |  27 +
 .../weex-vue-event/src/index.js                 |   2 +
 .../weex-vue-geolocation/README.md              |   3 +
 .../weex-vue-geolocation/package.json           |  27 +
 .../weex-vue-geolocation/src/index.js           |   2 +
 .../weex-vue-global-event/README.md             |   3 +
 .../weex-vue-global-event/package.json          |  27 +
 .../weex-vue-global-event/src/index.js          |   2 +
 .../weex-vue-plugins/weex-vue-input/README.md   |   3 +
 .../weex-vue-input/package.json                 |  26 +
 .../weex-vue-input/src/index.js                 |   2 +
 .../weex-vue-plugins/weex-vue-modal/README.md   |   3 +
 .../weex-vue-modal/package.json                 |  27 +
 .../weex-vue-modal/src/index.js                 |   2 +
 .../weex-vue-navigator/README.md                |   3 +
 .../weex-vue-navigator/package.json             |  27 +
 .../weex-vue-navigator/src/index.js             |   2 +
 .../weex-vue-plugins/weex-vue-slider/README.md  |   3 +
 .../weex-vue-slider/package.json                |  27 +
 .../weex-vue-slider/src/index.js                |   2 +
 .../weex-vue-plugins/weex-vue-storage/README.md |   3 +
 .../weex-vue-storage/package.json               |  27 +
 .../weex-vue-storage/src/index.js               |   2 +
 .../weex-vue-plugins/weex-vue-stream/README.md  |   3 +
 .../weex-vue-stream/package.json                |  27 +
 .../weex-vue-stream/src/index.js                |   2 +
 .../weex-vue-plugins/weex-vue-switch/README.md  |   3 +
 .../weex-vue-switch/package.json                |  26 +
 .../weex-vue-switch/src/index.js                |   2 +
 .../weex-vue-textarea/.DS_Store                 | Bin 0 -> 6148 bytes
 .../weex-vue-textarea/README.md                 |   3 +
 .../weex-vue-textarea/package.json              |  26 +
 .../weex-vue-textarea/src/index.js              |   2 +
 .../weex-vue-plugins/weex-vue-video/README.md   |   3 +
 .../weex-vue-video/package.json                 |  26 +
 .../weex-vue-video/src/index.js                 |   2 +
 .../weex-vue-plugins/weex-vue-web/README.md     |   3 +
 .../weex-vue-plugins/weex-vue-web/package.json  |  26 +
 .../weex-vue-plugins/weex-vue-web/src/index.js  |   2 +
 .../weex-vue-websocket/README.md                |   3 +
 .../weex-vue-websocket/package.json             |  27 +
 .../weex-vue-websocket/src/index.js             |   2 +
 .../weex-vue-plugins/weex-vue-webview/README.md |   3 +
 .../weex-vue-webview/package.json               |  27 +
 .../weex-vue-webview/src/index.js               |   2 +
 packages/weex-vue-render/README.md              |  77 +++
 packages/weex-vue-render/package.json           |   9 +-
 packages/weex-vue-render/src/index.core.js      |  13 +
 packages/weex-vue-render/src/index.js           |  12 +
 scripts/dist-vue.sh                             |   2 +-
 vue.html                                        |   8 +-
 136 files changed, 2952 insertions(+), 2176 deletions(-)
----------------------------------------------------------------------



[05/12] incubator-weex git commit: + [ios] update pod file

Posted by ac...@apache.org.
+ [ios] update pod file


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/c4c77dc9
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/c4c77dc9
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/c4c77dc9

Branch: refs/heads/0.16-dev
Commit: c4c77dc902e5136887eae95af38cd106402375b5
Parents: ee9b1c7
Author: 齐山 <su...@163.com>
Authored: Wed Jul 26 17:47:04 2017 +0800
Committer: 齐山 <su...@163.com>
Committed: Wed Jul 26 17:47:04 2017 +0800

----------------------------------------------------------------------
 ios/playground/Podfile | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c4c77dc9/ios/playground/Podfile
----------------------------------------------------------------------
diff --git a/ios/playground/Podfile b/ios/playground/Podfile
index bda8b39..50afc6b 100644
--- a/ios/playground/Podfile
+++ b/ios/playground/Podfile
@@ -4,7 +4,7 @@ platform :ios, '7.0'
 
 def common
     pod 'WeexSDK', :path=>'../../'
-    pod 'WXDevtool', '0.9.5'
+    pod 'WXDevtool', '0.15.1'
     pod 'SDWebImage', '3.7.5'
     pod 'SocketRocket', '0.4.2'
     pod 'ATSDK-Weex', '0.0.1'


[11/12] incubator-weex git commit: Merge remote-tracking branch 'wip-us/0.15-dev' into wip-us-0.16-dev

Posted by ac...@apache.org.
Merge remote-tracking branch 'wip-us/0.15-dev' into wip-us-0.16-dev


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/2377bf68
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/2377bf68
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/2377bf68

Branch: refs/heads/0.16-dev
Commit: 2377bf685b6b112a21b655f4f22eeeda9b5cc502
Parents: 495fc6b eb48b94
Author: acton393 <zh...@gmail.com>
Authored: Sat Jul 29 10:52:50 2017 +0800
Committer: acton393 <zh...@gmail.com>
Committed: Sat Jul 29 10:52:50 2017 +0800

----------------------------------------------------------------------
 .../src/main/java/com/taobao/weex/WXSDKInstance.java | 11 +++++++++--
 .../weex/ui/component/list/BasicListComponent.java   | 15 +++++++++++++--
 ios/sdk/WeexSDK.xcodeproj/project.pbxproj            |  4 ++++
 ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.h   |  1 -
 ios/sdk/WeexSDK/Sources/Module/WXWebSocketModule.m   |  1 +
 5 files changed, 27 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/2377bf68/android/sdk/src/main/java/com/taobao/weex/WXSDKInstance.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
index bdec22e..b85ec21 100644
--- a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
@@ -92,6 +92,7 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
   private int mListCellCount = 0;
   private boolean mForceLoadmoreNextTime = false;
   private ArrayList<ListBaseViewHolder> recycleViewList = new ArrayList<>();
+  private static int visibleCellCount = 6;
   private static final Pattern transformPattern = Pattern.compile("([a-z]+)\\(([0-9\\.]+),?([0-9\\.]+)?\\)");
 
   private Map<String, AppearanceHelper> mAppearComponents = new HashMap<>();
@@ -818,11 +819,18 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
     if(holder.canRecycled()) {
       recycleViewList.add(holder);
 
+      // recycleViewList allowed max size
+      int threshold = visibleCellCount >= 6 ? (visibleCellCount * 6) : (6*6);
+
       /**
        * Recycle cache{@link recycleViewList} when recycleViewList.size() > list max child count
        */
-      if (recycleViewList.size() > getChildCount() + 1)
+      if (recycleViewList.size() > getChildCount() + 1 || recycleViewList.size() >= threshold) {
+        WXLogUtils.d(TAG, "Recycle holder list recycled : cache size is " + recycleViewList.size() +
+                ", visibleCellCount is " + visibleCellCount + ", threshold is " + threshold +
+                ", child count is " + getChildCount());
         recycleViewHolderList();
+      }
     } else {
       WXLogUtils.w(TAG, "this holder can not be allowed to  recycled" );
     }
@@ -1188,6 +1196,8 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
       direction = directionX > 0 ? Constants.Value.DIRECTION_LEFT : Constants.Value.DIRECTION_RIGHT;
     }
 
+    visibleCellCount = lastVisible - firstVisible;
+
     while (it.hasNext()) {
       AppearanceHelper item = it.next();
       WXComponent component = item.getAwareChild();


[10/12] incubator-weex git commit: * [ios] add tracing manager to dynamic framework

Posted by ac...@apache.org.
* [ios] add tracing manager to dynamic framework


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/eb48b94c
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/eb48b94c
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/eb48b94c

Branch: refs/heads/0.16-dev
Commit: eb48b94c7200a8515044755417a76ae63fef5b68
Parents: 6b9f862
Author: acton393 <zh...@gmail.com>
Authored: Fri Jul 28 22:15:05 2017 +0800
Committer: acton393 <zh...@gmail.com>
Committed: Fri Jul 28 22:15:05 2017 +0800

----------------------------------------------------------------------
 ios/sdk/WeexSDK.xcodeproj/project.pbxproj | 4 ++++
 1 file changed, 4 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/eb48b94c/ios/sdk/WeexSDK.xcodeproj/project.pbxproj
----------------------------------------------------------------------
@@ -818,11 +819,18 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
       /**
-       * Recycle cache{@link recycleViewList} when recycleViewList.size() > list max child count
+       * Recycle cache{@link recycleViewList} when recycleViewList.size() > list max child count or threshold
        */